@@ -3,8 +3,7 @@ import sys
 import logging
 from datetime import datetime
 from typing import Union
-from .. import __version__
-from ..utils import load_mle_toolbox_config
+from .. import __version__, mle_config
 from ..protocol import protocol_summary, load_local_protocol_db
 from ..remote.gcloud_transfer import get_gcloud_db
 
@@ -23,7 +22,8 @@ def welcome_to_mle_toolbox(verbose=False):
     print(72*" " + "@RobertTLange")
     print(85*"=")
     time_t = datetime.now().strftime("%m/%d/%Y %I:%M:%S %p")
-    print(time_t, f"Thx for using MLE-Toolbox {__version__} Locally, on SGE, Slurm or GCP")
+    print(time_t, f"Thx for using MLE-Toolbox {__version__}"
+                  f" Locally, on SGE or Slurm or Clusters.")
     if verbose:
         print(time_t, "It implements the following experiment types:")
         print("  - single-experiment: Run a single configuration experiment.")
@@ -79,11 +79,9 @@ def check_job_config(job_config: dict):
 
 def ask_for_experiment_id(repeated_question: bool=False):
     """ Helper function asking user for experiment id from protocol log. """
-    # Load cluster config
-    cc = load_mle_toolbox_config()
     # Get most recent/up-to-date experiment DB from Google Cloud Storage
     if not repeated_question:
-        if cc.general.use_gcloud_protocol_sync:
+        if mle_config.general.use_gcloud_protocol_sync:
             accessed_remote_db = get_gcloud_db()
         else:
             accessed_remote_db = False
