@@ -1,5 +1,8 @@
 try:
     import matplotlib
+    # Suppress all axis/future warnings from mpl
+    import warnings
+    warnings.filterwarnings("ignore", module="matplotlib\..*")
 except ModuleNotFoundError as err:
     raise ModuleNotFoundError(f"{err}. You need to install `matplotlib` "
                               "to use the `mle_toolbox.visualize` module.")
